/*
  PWMtests_MEGA
  Tests the PWM value of HerkuleX servos thanks to the HerkuleXLib
  (see www.benoitpuel.com/blog/telechargements/) using an Arduino MEGA 
  board.

  The serial terminal is used to printout messages.

  This example code is in the public domain.

  modified 19 February 2016
  by Benoit Puel
 */

#include <HkxContRotation.h>

// global variables
byte ID = 253; // ID of the servo
HkxPrint* printoutLib;
HkxPrint* printoutCode;
HkxCommunication* communication;
HkxSetup* setupServos;
String message;

void setup() {
  delay(2000); // wait 2 seconds to open the serial monitor

  printoutLib = new HkxPrint(Serial, 9600);  // Printout errors on the serial monitor
  printoutCode = new HkxPrint(*printoutLib, true, true, true);  // Printout errors on the serial monitor
  communication = new HkxCommunication(HKX_115200, Serial1, *printoutLib);  // Communication with the servo on Serial1
  setupServos = new HkxSetup(*communication, *printoutLib);  // setup the servos

  setupServos->clearOneStatus(ID);
  
  // modify the control system
  setupServos->setAllControlSystem (440, 8000, 0, 0, 0);
  
  // place the servo in position
  setupServos->setOneTorqueLEDControl(ID, HKX_TORQUE_FREE, HKX_LED_BLUE);
  printoutCode->infoPrint("Please place the servo in horizontal position");
  delay(5000);
  setupServos->setOneTorqueLEDControl(ID, HKX_TORQUE_ON, HKX_LED_GREEN);
  printoutCode->infoPrint("Start acquisition");

  // Title for information display
  message = ";\t mVolt \t;\t PWM";
  printoutCode->infoPrint(message);
  delay(1000);

}

void loop() {
  uint16_t voltage;
  uint16_t PWM;

  // Get the behaviour
  byte error = setupServos->getBehaviour(ID, &voltage, HKX_NO_VALUE, HKX_NO_VALUE, HKX_NO_VALUE, HKX_NO_VALUE, HKX_NO_VALUE, &PWM, HKX_NO_VALUE, HKX_NO_VALUE, HKX_NO_VALUE);
  if(error == 0){
    message = ";\t ";
    message += voltage;
    message += " \t;\t ";
    message += PWM;
    printoutCode->infoPrint(message);
  } else if(error == 1){
    printoutCode->errorPrint("Input not correct");
  } else if(error == 2){
    printoutCode->errorPrint("Servo not connected");
  } else if(error == 3){
    printoutCode->errorPrint("Data not consistent");
  }
  
  delay(1000); // refresh every second
}
